==> nipper-0.10.4.tgz: nipper-0.10.4/CSS/cleanup.c <==
/***************************************************************************
 *   nipper - The network infrastructure parser                            *
 *   Copyright (C) 2006 - 2007 by Ian Ventura-Whiting (Fizz)               *
 *   fizz@titania.co.uk                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program. If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/


void cleanupCSS(struct nipperConfig *nipper)
{
	// Pointers...
	struct snmpCSSCommunity *snmpCSSCommunityPointer;
	struct snmpCSSHost *snmpCSSHostPointer;
	struct cssAclClause *cssAclClausePointer;
	struct cssAcl *cssAclPointer;

	// ACL
	while (nipper->css->acl != 0)
	{
		while (nipper->css->acl->clause != 0)
		{
			cssAclClausePointer = nipper->css->acl->clause->next;
			free (nipper->css->acl->clause);
			nipper->css->acl->clause = cssAclClausePointer;
		}
		cssAclPointer = nipper->css->acl->next;
		free (nipper->css->acl);
		nipper->css->acl = cssAclPointer;
	}

	// SNMP
	if (nipper->css->snmp != 0)
	{
		while (nipper->css->snmp->community != 0)
		{
			snmpCSSCommunityPointer = nipper->css->snmp->community->next;
			free (nipper->css->snmp->community);
			nipper->css->snmp->community = snmpCSSCommunityPointer;
		}
		while (nipper->css->snmp->host != 0)
		{
			snmpCSSHostPointer = nipper->css->snmp->host->next;
			free (nipper->css->snmp->host);
			nipper->css->snmp->host = snmpCSSHostPointer;
		}
		free (nipper->css->snmp);
	}

	// Cleanup CSS config
	free(nipper->css);
}

==> nipper-0.10.5.tgz: nipper-0.10.5/CSS/cleanup.c <==
/***************************************************************************
 *   nipper - The network infrastructure parser                            *
 *   Copyright (C) 2006 - 2007 by Ian Ventura-Whiting (Fizz)               *
 *   fizz@titania.co.uk                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program. If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/


void cleanupCSS(struct nipperConfig *nipper)
{
	// Pointers...
	struct snmpCSSCommunity *snmpCSSCommunityPointer = 0;
	struct snmpCSSHost *snmpCSSHostPointer = 0;
	struct cssAclClause *cssAclClausePointer = 0;
	struct cssAcl *cssAclPointer = 0;

	// ACL
	while (nipper->css->acl != 0)
	{
		while (nipper->css->acl->clause != 0)
		{
			cssAclClausePointer = nipper->css->acl->clause->next;
			free (nipper->css->acl->clause);
			nipper->css->acl->clause = cssAclClausePointer;
		}
		cssAclPointer = nipper->css->acl->next;
		free (nipper->css->acl);
		nipper->css->acl = cssAclPointer;
	}

	// SNMP
	if (nipper->css->snmp != 0)
	{
		while (nipper->css->snmp->community != 0)
		{
			snmpCSSCommunityPointer = nipper->css->snmp->community->next;
			free (nipper->css->snmp->community);
			nipper->css->snmp->community = snmpCSSCommunityPointer;
		}
		while (nipper->css->snmp->host != 0)
		{
			snmpCSSHostPointer = nipper->css->snmp->host->next;
			free (nipper->css->snmp->host);
			nipper->css->snmp->host = snmpCSSHostPointer;
		}
		free (nipper->css->snmp);
	}

	// Cleanup CSS config
	free(nipper->css);
}
